@@ -1,3 +1,6 @@
+c make next 1 if vector meson after collsion is to be deaayed
+c else put 0 then, vector meson is replaced by photon
+#define VECMESDECAY   0
 c  uncomment until   cgpHad and use make -f test.mk
 c
 c #include "BlockData/cblkGene.h"
@@ -383,6 +386,7 @@ c      ************************************************************
 c         neutral vector meson collision.
        subroutine cgVectorMeson(pj, tg, a, ntp)
        implicit none
+#include  "Zcode.h"
 #include  "Zptcl.h"
 
        record /ptcl/ pj, a(*), tg
@@ -407,8 +411,20 @@ c              leading v.m is in a(ntp)
 c              need to make decay of leading ptcl
             if(icon .eq. 0) then
                pw = a(ntp)
+#if VECMESDECAY == 1
                call cvmdcy(pw, a(ntp), nx)
                ntp=ntp -1 + nx
+#else
+               a(ntp).code = kphoton
+               a(ntp).mass = 0.
+               p=a(ntp).fm.p(4)
+               alfa=sqrt((a(ntp).fm.p(1)**2 + 
+     *               a(ntp).fm.p(2)**2 + a(ntp).fm.p(3)**2))
+     *         /p
+               a(ntp).fm.p(1) = a(ntp).fm.p(1)/alfa
+               a(ntp).fm.p(2) = a(ntp).fm.p(2)/alfa
+               a(ntp).fm.p(3) = a(ntp).fm.p(3)/alfa
+#endif
             else
                ntp = 1
                a(1) = pj
